"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildConcatenatedName = exports.cleanupTMPLiveFiles = exports.cleanupUnsavedNormalLive = exports.cleanupPermanentLive = void 0;
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const logger_1 = require("../../helpers/logger");
const paths_1 = require("../paths");
const live_segment_sha_store_1 = require("./live-segment-sha-store");
function buildConcatenatedName(segmentOrPlaylistPath) {
    const num = (0, path_1.basename)(segmentOrPlaylistPath).match(/^(\d+)(-|\.)/);
    return 'concat-' + num[1] + '.ts';
}
exports.buildConcatenatedName = buildConcatenatedName;
function cleanupPermanentLive(video, streamingPlaylist) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield cleanupTMPLiveFiles(video);
        yield streamingPlaylist.destroy();
    });
}
exports.cleanupPermanentLive = cleanupPermanentLive;
function cleanupUnsavedNormalLive(video, streamingPlaylist) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const hlsDirectory = (0, paths_1.getLiveDirectory)(video);
        yield (0, fs_extra_1.remove)(hlsDirectory);
        yield streamingPlaylist.destroy();
        live_segment_sha_store_1.LiveSegmentShaStore.Instance.cleanupShaSegments(video.uuid);
    });
}
exports.cleanupUnsavedNormalLive = cleanupUnsavedNormalLive;
function cleanupTMPLiveFiles(video) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const hlsDirectory = (0, paths_1.getLiveDirectory)(video);
        live_segment_sha_store_1.LiveSegmentShaStore.Instance.cleanupShaSegments(video.uuid);
        if (!(yield (0, fs_extra_1.pathExists)(hlsDirectory)))
            return;
        logger_1.logger.info('Cleanup TMP live files of %s.', hlsDirectory);
        const files = yield (0, fs_extra_1.readdir)(hlsDirectory);
        for (const filename of files) {
            if (filename.endsWith('.ts') ||
                filename.endsWith('.m3u8') ||
                filename.endsWith('.mpd') ||
                filename.endsWith('.m4s') ||
                filename.endsWith('.tmp')) {
                const p = (0, path_1.join)(hlsDirectory, filename);
                (0, fs_extra_1.remove)(p)
                    .catch(err => logger_1.logger.error('Cannot remove %s.', p, { err }));
            }
        }
    });
}
exports.cleanupTMPLiveFiles = cleanupTMPLiveFiles;
//# sourceMappingURL=live-utils.js.map