"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const core_utils_1 = require("../../../../shared/core-utils");
const server_commands_1 = require("../../../../shared/server-commands");
function checkInitialConfig(server, data) {
    (0, chai_1.expect)(data.instance.name).to.equal('PeerTube');
    (0, chai_1.expect)(data.instance.shortDescription).to.equal('PeerTube, an ActivityPub-federated video streaming platform using P2P directly in your web browser.');
    (0, chai_1.expect)(data.instance.description).to.equal('Welcome to this PeerTube instance!');
    (0, chai_1.expect)(data.instance.terms).to.equal('No terms for now.');
    (0, chai_1.expect)(data.instance.creationReason).to.be.empty;
    (0, chai_1.expect)(data.instance.codeOfConduct).to.be.empty;
    (0, chai_1.expect)(data.instance.moderationInformation).to.be.empty;
    (0, chai_1.expect)(data.instance.administrator).to.be.empty;
    (0, chai_1.expect)(data.instance.maintenanceLifetime).to.be.empty;
    (0, chai_1.expect)(data.instance.businessModel).to.be.empty;
    (0, chai_1.expect)(data.instance.hardwareInformation).to.be.empty;
    (0, chai_1.expect)(data.instance.languages).to.have.lengthOf(0);
    (0, chai_1.expect)(data.instance.categories).to.have.lengthOf(0);
    (0, chai_1.expect)(data.instance.defaultClientRoute).to.equal('/videos/trending');
    (0, chai_1.expect)(data.instance.isNSFW).to.be.false;
    (0, chai_1.expect)(data.instance.defaultNSFWPolicy).to.equal('display');
    (0, chai_1.expect)(data.instance.customizations.css).to.be.empty;
    (0, chai_1.expect)(data.instance.customizations.javascript).to.be.empty;
    (0, chai_1.expect)(data.services.twitter.username).to.equal('@Chocobozzz');
    (0, chai_1.expect)(data.services.twitter.whitelisted).to.be.false;
    (0, chai_1.expect)(data.client.videos.miniature.preferAuthorDisplayName).to.be.false;
    (0, chai_1.expect)(data.client.menu.login.redirectOnSingleExternalAuth).to.be.false;
    (0, chai_1.expect)(data.cache.previews.size).to.equal(1);
    (0, chai_1.expect)(data.cache.captions.size).to.equal(1);
    (0, chai_1.expect)(data.cache.torrents.size).to.equal(1);
    (0, chai_1.expect)(data.signup.enabled).to.be.true;
    (0, chai_1.expect)(data.signup.limit).to.equal(4);
    (0, chai_1.expect)(data.signup.minimumAge).to.equal(16);
    (0, chai_1.expect)(data.signup.requiresEmailVerification).to.be.false;
    (0, chai_1.expect)(data.admin.email).to.equal('admin' + server.internalServerNumber + '@example.com');
    (0, chai_1.expect)(data.contactForm.enabled).to.be.true;
    (0, chai_1.expect)(data.user.videoQuota).to.equal(5242880);
    (0, chai_1.expect)(data.user.videoQuotaDaily).to.equal(-1);
    (0, chai_1.expect)(data.videoChannels.maxPerUser).to.equal(20);
    (0, chai_1.expect)(data.transcoding.enabled).to.be.false;
    (0, chai_1.expect)(data.transcoding.allowAdditionalExtensions).to.be.false;
    (0, chai_1.expect)(data.transcoding.allowAudioFiles).to.be.false;
    (0, chai_1.expect)(data.transcoding.threads).to.equal(2);
    (0, chai_1.expect)(data.transcoding.concurrency).to.equal(2);
    (0, chai_1.expect)(data.transcoding.profile).to.equal('default');
    (0, chai_1.expect)(data.transcoding.resolutions['144p']).to.be.false;
    (0, chai_1.expect)(data.transcoding.resolutions['240p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['360p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['480p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['720p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['1080p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['1440p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['2160p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.alwaysTranscodeOriginalResolution).to.be.true;
    (0, chai_1.expect)(data.transcoding.webtorrent.enabled).to.be.true;
    (0, chai_1.expect)(data.transcoding.hls.enabled).to.be.true;
    (0, chai_1.expect)(data.live.enabled).to.be.false;
    (0, chai_1.expect)(data.live.allowReplay).to.be.false;
    (0, chai_1.expect)(data.live.latencySetting.enabled).to.be.true;
    (0, chai_1.expect)(data.live.maxDuration).to.equal(-1);
    (0, chai_1.expect)(data.live.maxInstanceLives).to.equal(20);
    (0, chai_1.expect)(data.live.maxUserLives).to.equal(3);
    (0, chai_1.expect)(data.live.transcoding.enabled).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.threads).to.equal(2);
    (0, chai_1.expect)(data.live.transcoding.profile).to.equal('default');
    (0, chai_1.expect)(data.live.transcoding.resolutions['144p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.resolutions['240p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.resolutions['360p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.resolutions['480p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.resolutions['720p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.resolutions['1080p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.resolutions['1440p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.resolutions['2160p']).to.be.false;
    (0, chai_1.expect)(data.live.transcoding.alwaysTranscodeOriginalResolution).to.be.true;
    (0, chai_1.expect)(data.videoStudio.enabled).to.be.false;
    (0, chai_1.expect)(data.import.videos.concurrency).to.equal(2);
    (0, chai_1.expect)(data.import.videos.http.enabled).to.be.true;
    (0, chai_1.expect)(data.import.videos.torrent.enabled).to.be.true;
    (0, chai_1.expect)(data.autoBlacklist.videos.ofUsers.enabled).to.be.false;
    (0, chai_1.expect)(data.followers.instance.enabled).to.be.true;
    (0, chai_1.expect)(data.followers.instance.manualApproval).to.be.false;
    (0, chai_1.expect)(data.followings.instance.autoFollowBack.enabled).to.be.false;
    (0, chai_1.expect)(data.followings.instance.autoFollowIndex.enabled).to.be.false;
    (0, chai_1.expect)(data.followings.instance.autoFollowIndex.indexUrl).to.equal('');
    (0, chai_1.expect)(data.broadcastMessage.enabled).to.be.false;
    (0, chai_1.expect)(data.broadcastMessage.level).to.equal('info');
    (0, chai_1.expect)(data.broadcastMessage.message).to.equal('');
    (0, chai_1.expect)(data.broadcastMessage.dismissable).to.be.false;
}
function checkUpdatedConfig(data) {
    (0, chai_1.expect)(data.instance.name).to.equal('PeerTube updated');
    (0, chai_1.expect)(data.instance.shortDescription).to.equal('my short description');
    (0, chai_1.expect)(data.instance.description).to.equal('my super description');
    (0, chai_1.expect)(data.instance.terms).to.equal('my super terms');
    (0, chai_1.expect)(data.instance.creationReason).to.equal('my super creation reason');
    (0, chai_1.expect)(data.instance.codeOfConduct).to.equal('my super coc');
    (0, chai_1.expect)(data.instance.moderationInformation).to.equal('my super moderation information');
    (0, chai_1.expect)(data.instance.administrator).to.equal('Kuja');
    (0, chai_1.expect)(data.instance.maintenanceLifetime).to.equal('forever');
    (0, chai_1.expect)(data.instance.businessModel).to.equal('my super business model');
    (0, chai_1.expect)(data.instance.hardwareInformation).to.equal('2vCore 3GB RAM');
    (0, chai_1.expect)(data.instance.languages).to.deep.equal(['en', 'es']);
    (0, chai_1.expect)(data.instance.categories).to.deep.equal([1, 2]);
    (0, chai_1.expect)(data.instance.defaultClientRoute).to.equal('/videos/recently-added');
    (0, chai_1.expect)(data.instance.isNSFW).to.be.true;
    (0, chai_1.expect)(data.instance.defaultNSFWPolicy).to.equal('blur');
    (0, chai_1.expect)(data.instance.customizations.javascript).to.equal('alert("coucou")');
    (0, chai_1.expect)(data.instance.customizations.css).to.equal('body { background-color: red; }');
    (0, chai_1.expect)(data.services.twitter.username).to.equal('@Kuja');
    (0, chai_1.expect)(data.services.twitter.whitelisted).to.be.true;
    (0, chai_1.expect)(data.client.videos.miniature.preferAuthorDisplayName).to.be.true;
    (0, chai_1.expect)(data.client.menu.login.redirectOnSingleExternalAuth).to.be.true;
    (0, chai_1.expect)(data.cache.previews.size).to.equal(2);
    (0, chai_1.expect)(data.cache.captions.size).to.equal(3);
    (0, chai_1.expect)(data.cache.torrents.size).to.equal(4);
    (0, chai_1.expect)(data.signup.enabled).to.be.false;
    (0, chai_1.expect)(data.signup.limit).to.equal(5);
    (0, chai_1.expect)(data.signup.requiresEmailVerification).to.be.false;
    (0, chai_1.expect)(data.signup.minimumAge).to.equal(10);
    if ((0, core_utils_1.parallelTests)() === false) {
        (0, chai_1.expect)(data.admin.email).to.equal('superadmin1@example.com');
    }
    (0, chai_1.expect)(data.contactForm.enabled).to.be.false;
    (0, chai_1.expect)(data.user.videoQuota).to.equal(5242881);
    (0, chai_1.expect)(data.user.videoQuotaDaily).to.equal(318742);
    (0, chai_1.expect)(data.videoChannels.maxPerUser).to.equal(24);
    (0, chai_1.expect)(data.transcoding.enabled).to.be.true;
    (0, chai_1.expect)(data.transcoding.threads).to.equal(1);
    (0, chai_1.expect)(data.transcoding.concurrency).to.equal(3);
    (0, chai_1.expect)(data.transcoding.allowAdditionalExtensions).to.be.true;
    (0, chai_1.expect)(data.transcoding.allowAudioFiles).to.be.true;
    (0, chai_1.expect)(data.transcoding.profile).to.equal('vod_profile');
    (0, chai_1.expect)(data.transcoding.resolutions['144p']).to.be.false;
    (0, chai_1.expect)(data.transcoding.resolutions['240p']).to.be.false;
    (0, chai_1.expect)(data.transcoding.resolutions['360p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['480p']).to.be.true;
    (0, chai_1.expect)(data.transcoding.resolutions['720p']).to.be.false;
    (0, chai_1.expect)(data.transcoding.resolutions['1080p']).to.be.false;
    (0, chai_1.expect)(data.transcoding.resolutions['2160p']).to.be.false;
    (0, chai_1.expect)(data.transcoding.alwaysTranscodeOriginalResolution).to.be.false;
    (0, chai_1.expect)(data.transcoding.hls.enabled).to.be.false;
    (0, chai_1.expect)(data.transcoding.webtorrent.enabled).to.be.true;
    (0, chai_1.expect)(data.live.enabled).to.be.true;
    (0, chai_1.expect)(data.live.allowReplay).to.be.true;
    (0, chai_1.expect)(data.live.latencySetting.enabled).to.be.false;
    (0, chai_1.expect)(data.live.maxDuration).to.equal(5000);
    (0, chai_1.expect)(data.live.maxInstanceLives).to.equal(-1);
    (0, chai_1.expect)(data.live.maxUserLives).to.equal(10);
    (0, chai_1.expect)(data.live.transcoding.enabled).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.threads).to.equal(4);
    (0, chai_1.expect)(data.live.transcoding.profile).to.equal('live_profile');
    (0, chai_1.expect)(data.live.transcoding.resolutions['144p']).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.resolutions['240p']).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.resolutions['360p']).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.resolutions['480p']).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.resolutions['720p']).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.resolutions['1080p']).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.resolutions['2160p']).to.be.true;
    (0, chai_1.expect)(data.live.transcoding.alwaysTranscodeOriginalResolution).to.be.false;
    (0, chai_1.expect)(data.videoStudio.enabled).to.be.true;
    (0, chai_1.expect)(data.import.videos.concurrency).to.equal(4);
    (0, chai_1.expect)(data.import.videos.http.enabled).to.be.false;
    (0, chai_1.expect)(data.import.videos.torrent.enabled).to.be.false;
    (0, chai_1.expect)(data.autoBlacklist.videos.ofUsers.enabled).to.be.true;
    (0, chai_1.expect)(data.followers.instance.enabled).to.be.false;
    (0, chai_1.expect)(data.followers.instance.manualApproval).to.be.true;
    (0, chai_1.expect)(data.followings.instance.autoFollowBack.enabled).to.be.true;
    (0, chai_1.expect)(data.followings.instance.autoFollowIndex.enabled).to.be.true;
    (0, chai_1.expect)(data.followings.instance.autoFollowIndex.indexUrl).to.equal('https://updated.example.com');
    (0, chai_1.expect)(data.broadcastMessage.enabled).to.be.true;
    (0, chai_1.expect)(data.broadcastMessage.level).to.equal('error');
    (0, chai_1.expect)(data.broadcastMessage.message).to.equal('super bad message');
    (0, chai_1.expect)(data.broadcastMessage.dismissable).to.be.true;
}
const newCustomConfig = {
    instance: {
        name: 'PeerTube updated',
        shortDescription: 'my short description',
        description: 'my super description',
        terms: 'my super terms',
        codeOfConduct: 'my super coc',
        creationReason: 'my super creation reason',
        moderationInformation: 'my super moderation information',
        administrator: 'Kuja',
        maintenanceLifetime: 'forever',
        businessModel: 'my super business model',
        hardwareInformation: '2vCore 3GB RAM',
        languages: ['en', 'es'],
        categories: [1, 2],
        isNSFW: true,
        defaultNSFWPolicy: 'blur',
        defaultClientRoute: '/videos/recently-added',
        customizations: {
            javascript: 'alert("coucou")',
            css: 'body { background-color: red; }'
        }
    },
    theme: {
        default: 'default'
    },
    services: {
        twitter: {
            username: '@Kuja',
            whitelisted: true
        }
    },
    client: {
        videos: {
            miniature: {
                preferAuthorDisplayName: true
            }
        },
        menu: {
            login: {
                redirectOnSingleExternalAuth: true
            }
        }
    },
    cache: {
        previews: {
            size: 2
        },
        captions: {
            size: 3
        },
        torrents: {
            size: 4
        }
    },
    signup: {
        enabled: false,
        limit: 5,
        requiresEmailVerification: false,
        minimumAge: 10
    },
    admin: {
        email: 'superadmin1@example.com'
    },
    contactForm: {
        enabled: false
    },
    user: {
        videoQuota: 5242881,
        videoQuotaDaily: 318742
    },
    videoChannels: {
        maxPerUser: 24
    },
    transcoding: {
        enabled: true,
        allowAdditionalExtensions: true,
        allowAudioFiles: true,
        threads: 1,
        concurrency: 3,
        profile: 'vod_profile',
        resolutions: {
            '0p': false,
            '144p': false,
            '240p': false,
            '360p': true,
            '480p': true,
            '720p': false,
            '1080p': false,
            '1440p': false,
            '2160p': false
        },
        alwaysTranscodeOriginalResolution: false,
        webtorrent: {
            enabled: true
        },
        hls: {
            enabled: false
        }
    },
    live: {
        enabled: true,
        allowReplay: true,
        latencySetting: {
            enabled: false
        },
        maxDuration: 5000,
        maxInstanceLives: -1,
        maxUserLives: 10,
        transcoding: {
            enabled: true,
            threads: 4,
            profile: 'live_profile',
            resolutions: {
                '144p': true,
                '240p': true,
                '360p': true,
                '480p': true,
                '720p': true,
                '1080p': true,
                '1440p': true,
                '2160p': true
            },
            alwaysTranscodeOriginalResolution: false
        }
    },
    videoStudio: {
        enabled: true
    },
    import: {
        videos: {
            concurrency: 4,
            http: {
                enabled: false
            },
            torrent: {
                enabled: false
            }
        },
        videoChannelSynchronization: {
            enabled: false,
            maxPerUser: 10
        }
    },
    trending: {
        videos: {
            algorithms: {
                enabled: ['hot', 'most-viewed', 'most-liked'],
                default: 'hot'
            }
        }
    },
    autoBlacklist: {
        videos: {
            ofUsers: {
                enabled: true
            }
        }
    },
    followers: {
        instance: {
            enabled: false,
            manualApproval: true
        }
    },
    followings: {
        instance: {
            autoFollowBack: {
                enabled: true
            },
            autoFollowIndex: {
                enabled: true,
                indexUrl: 'https://updated.example.com'
            }
        }
    },
    broadcastMessage: {
        enabled: true,
        level: 'error',
        message: 'super bad message',
        dismissable: true
    },
    search: {
        remoteUri: {
            anonymous: true,
            users: true
        },
        searchIndex: {
            enabled: true,
            url: 'https://search.joinpeertube.org',
            disableLocalSearch: true,
            isDefaultSearch: true
        }
    }
};
describe('Test static config', function () {
    let server = null;
    before(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(30000);
            server = yield (0, server_commands_1.createSingleServer)(1, { webadmin: { configuration: { edition: { allowed: false } } } });
            yield (0, server_commands_1.setAccessTokensToServers)([server]);
        });
    });
    it('Should tell the client that edits are not allowed', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield server.config.getConfig();
            (0, chai_1.expect)(data.webadmin.configuration.edition.allowed).to.be.false;
        });
    });
    it('Should error when client tries to update', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield server.config.updateCustomConfig({ newCustomConfig, expectedStatus: 405 });
        });
    });
    after(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield (0, server_commands_1.cleanupTests)([server]);
        });
    });
});
describe('Test config', function () {
    let server = null;
    before(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(30000);
            server = yield (0, server_commands_1.createSingleServer)(1);
            yield (0, server_commands_1.setAccessTokensToServers)([server]);
        });
    });
    it('Should have a correct config on a server with registration enabled', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield server.config.getConfig();
            (0, chai_1.expect)(data.signup.allowed).to.be.true;
        });
    });
    it('Should have a correct config on a server with registration enabled and a users limit', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(5000);
            yield Promise.all([
                server.users.register({ username: 'user1' }),
                server.users.register({ username: 'user2' }),
                server.users.register({ username: 'user3' })
            ]);
            const data = yield server.config.getConfig();
            (0, chai_1.expect)(data.signup.allowed).to.be.false;
        });
    });
    it('Should have the correct video allowed extensions', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield server.config.getConfig();
            (0, chai_1.expect)(data.video.file.extensions).to.have.lengthOf(3);
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.mp4');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.webm');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.ogv');
            yield server.videos.upload({ attributes: { fixture: 'video_short.mkv' }, expectedStatus: 415 });
            yield server.videos.upload({ attributes: { fixture: 'sample.ogg' }, expectedStatus: 415 });
            (0, chai_1.expect)(data.contactForm.enabled).to.be.true;
        });
    });
    it('Should get the customized configuration', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield server.config.getCustomConfig();
            checkInitialConfig(server, data);
        });
    });
    it('Should update the customized configuration', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield server.config.updateCustomConfig({ newCustomConfig });
            const data = yield server.config.getCustomConfig();
            checkUpdatedConfig(data);
        });
    });
    it('Should have the correct updated video allowed extensions', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(30000);
            const data = yield server.config.getConfig();
            (0, chai_1.expect)(data.video.file.extensions).to.have.length.above(4);
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.mp4');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.webm');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.ogv');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.flv');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.wmv');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.mkv');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.mp3');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.ogg');
            (0, chai_1.expect)(data.video.file.extensions).to.contain('.flac');
            yield server.videos.upload({ attributes: { fixture: 'video_short.mkv' }, expectedStatus: 200 });
            yield server.videos.upload({ attributes: { fixture: 'sample.ogg' }, expectedStatus: 200 });
        });
    });
    it('Should have the configuration updated after a restart', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(30000);
            yield (0, server_commands_1.killallServers)([server]);
            yield server.run();
            const data = yield server.config.getCustomConfig();
            checkUpdatedConfig(data);
        });
    });
    it('Should fetch the about information', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield server.config.getAbout();
            (0, chai_1.expect)(data.instance.name).to.equal('PeerTube updated');
            (0, chai_1.expect)(data.instance.shortDescription).to.equal('my short description');
            (0, chai_1.expect)(data.instance.description).to.equal('my super description');
            (0, chai_1.expect)(data.instance.terms).to.equal('my super terms');
            (0, chai_1.expect)(data.instance.codeOfConduct).to.equal('my super coc');
            (0, chai_1.expect)(data.instance.creationReason).to.equal('my super creation reason');
            (0, chai_1.expect)(data.instance.moderationInformation).to.equal('my super moderation information');
            (0, chai_1.expect)(data.instance.administrator).to.equal('Kuja');
            (0, chai_1.expect)(data.instance.maintenanceLifetime).to.equal('forever');
            (0, chai_1.expect)(data.instance.businessModel).to.equal('my super business model');
            (0, chai_1.expect)(data.instance.hardwareInformation).to.equal('2vCore 3GB RAM');
            (0, chai_1.expect)(data.instance.languages).to.deep.equal(['en', 'es']);
            (0, chai_1.expect)(data.instance.categories).to.deep.equal([1, 2]);
        });
    });
    it('Should remove the custom configuration', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(10000);
            yield server.config.deleteCustomConfig();
            const data = yield server.config.getCustomConfig();
            checkInitialConfig(server, data);
        });
    });
    it('Should enable frameguard', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(25000);
            {
                const res = yield (0, server_commands_1.makeGetRequest)({
                    url: server.url,
                    path: '/api/v1/config',
                    expectedStatus: 200
                });
                (0, chai_1.expect)(res.headers['x-frame-options']).to.exist;
            }
            yield (0, server_commands_1.killallServers)([server]);
            const config = {
                security: {
                    frameguard: { enabled: false }
                }
            };
            yield server.run(config);
            {
                const res = yield (0, server_commands_1.makeGetRequest)({
                    url: server.url,
                    path: '/api/v1/config',
                    expectedStatus: 200
                });
                (0, chai_1.expect)(res.headers['x-frame-options']).to.not.exist;
            }
        });
    });
    after(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield (0, server_commands_1.cleanupTests)([server]);
        });
    });
});
//# sourceMappingURL=config.js.map